Module hash

Module hash 

Cryptographic hash function implementations with enhanced type safety

This module provides implementations of various cryptographic hash functions with improved type-level guarantees and method chaining for ergonomic usage.

Re-exports

pub use blake2::Blake2b;
pub use blake2::Blake2s;
pub use keccak::Keccak256;
pub use sha1::Sha1;
pub use sha2::Sha224;
pub use sha2::Sha256;
pub use sha2::Sha384;
pub use sha2::Sha512;
pub use sha3::Sha3_224;
pub use sha3::Sha3_256;
pub use sha3::Sha3_384;
pub use sha3::Sha3_512;
pub use shake::Shake128;
pub use shake::Shake256;

Modules

blake2
BLAKE2 hash function implementations
keccak
Keccak-256 hash function implementation (Ethereum compatible)
sha1
SHA-1 hash function
sha2
SHA-2 hash function implementations with enhanced memory safety
sha3
SHA-3 hash function implementations
shake
SHAKE hash functions with fixed output length

Structs

EnhancedSha256
Implementation of enhanced Sha256 using the new trait structure

Enums

Sha256Algorithm
Marker type for SHA-256 algorithm

Traits

HashAlgorithm
Marker trait for hash algorithms with compile-time guarantees
HashFunction
Trait for cryptographic hash functions with improved type safety.

Type Aliases

Hash
A byte-vector hash result for backward compatibility.