Message Authentication Code (MAC) implementations with type-safe interfaces
This module contains implementations of various Message Authentication Codes (MACs) used throughout the dcrypt library, with improved type safety and ergonomic APIs.
Re-exports
pub use hmac::Hmac;pub use poly1305::Poly1305;pub use poly1305::POLY1305_KEY_SIZE;pub use poly1305::POLY1305_TAG_SIZE;
Modules
- hmac
- HMAC (Hash-based Message Authentication Code)
- poly1305
- Poly1305 message authentication code Pure-Rust branch-free limb arithmetic implementation.
Structs
- Generic
MacBuilder - Generic MAC builder implementation
Traits
- Mac
- Trait for Message Authentication Code (MAC) algorithms
- MacAlgorithm
- Marker trait for MAC algorithms with algorithm-specific constants
- MacBuilder
- Operation for MAC operations
- MacExt
- Extension trait for reusable-key MAC implementations to provide builders.