Module hmac

Module hmac 

HMAC (Hash-based Message Authentication Code)

• RFC 2104 / FIPS 198-1 compliant • Key-derived padding and hash state are zeroized on drop • Tag bytes are compared in constant time after an exact-length check

Structs

Hmac
HMAC implementation with constant-time tag-byte comparison.