pub struct Hmac<H: HashFunction + Clone + Zeroize> { /* private fields */ }Expand description
HMAC implementation with constant-time tag-byte comparison.
Implementations
Sourceimpl<H> Hmac<H>
impl<H> Hmac<H>
Sourcepub fn finalize(&mut self) -> Result<ZeroizingBytes>
pub fn finalize(&mut self) -> Result<ZeroizingBytes>
Finalise and return the tag.
Sourcepub fn verify(key: &[u8], data: &[u8], tag: &[u8]) -> Result<bool>
pub fn verify(key: &[u8], data: &[u8], tag: &[u8]) -> Result<bool>
Fixed-width verification of tag against key / data.
Tag bytes are accumulated without an early exit. Public lengths, hash errors, allocation, and the returned boolean still have ordinary control flow, so this is not a whole-operation constant-time guarantee.