Module stream

Module stream 

Stream cipher implementations

This module provides implementations of stream ciphers, which are symmetric key ciphers that encrypt plaintext digits one at a time with a pseudorandom keystream.

Available Stream Ciphers

  • ChaCha20: A high-speed stream cipher designed by Daniel J. Bernstein

Security Considerations

Stream ciphers require unique nonces for each encryption operation with the same key. Reusing a nonce with the same key completely breaks the security of the cipher.

Re-exports

pub use chacha::chacha20::ChaCha20;
pub use chacha::chacha20::CHACHA20_BLOCK_SIZE;
pub use chacha::chacha20::CHACHA20_KEY_SIZE;
pub use chacha::chacha20::CHACHA20_NONCE_SIZE;

Modules

chacha
ChaCha family of stream cipher implementations

Traits

StreamCipher
Common trait for stream cipher implementations